@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -38,6 +38,7 @@
 #include "gatchat.h"
 #include "gatresult.h"
 
+#include "common.h"
 #include "huaweimodem.h"
 
 static const char *none_prefix[] = { NULL };
@@ -56,10 +57,12 @@ static struct ofono_call *create_call(struct ofono_voicecall *vc, int type,
 	struct ofono_call *call;
 
 	/* Generate a call structure for the waiting call */
-	call = g_try_new0(struct ofono_call, 1);
-	if (!call)
+	call = g_try_new(struct ofono_call, 1);
+	if (call == NULL)
 		return NULL;
 
+	ofono_call_init(call);
+
 	call->id = id;
 	call->type = type;
 	call->direction = direction;
@@ -99,14 +102,10 @@ static void huawei_template(struct ofono_voicecall *vc, const char *cmd,
 	struct voicecall_data *vd = ofono_voicecall_get_data(vc);
 	struct cb_data *cbd = cb_data_new(cb, data);
 
-	if (!cbd)
-		goto error;
-
 	if (g_at_chat_send(vd->chat, cmd, none_prefix,
 				huawei_generic_cb, cbd, g_free) > 0)
 		return;
 
-error:
 	g_free(cbd);
 
 	CALLBACK_WITH_FAILURE(cb, data);
@@ -115,7 +114,6 @@ error:
 static void huawei_dial(struct ofono_voicecall *vc,
 				const struct ofono_phone_number *ph,
 				enum ofono_clir_option clir,
-				enum ofono_cug_option cug,
 				ofono_voicecall_cb_t cb, void *data)
 {
 	char buf[256];
@@ -136,14 +134,6 @@ static void huawei_dial(struct ofono_voicecall *vc,
 		break;
 	}
 
-	switch (cug) {
-	case OFONO_CUG_OPTION_INVOCATION:
-		strcat(buf, "G");
-		break;
-	default:
-		break;
-	}
-
 	strcat(buf, ";");
 
 	huawei_template(vc, buf, cb, data);
@@ -181,8 +171,9 @@ static void cring_notify(GAtResult *result, gpointer user_data)
 	int id;
 
 	/* CRING can repeat, ignore if we already have an incoming call */
-	if (g_slist_find_custom(vd->calls, GINT_TO_POINTER(4),
-					at_util_call_compare_by_status))
+	if (g_slist_find_custom(vd->calls,
+				GINT_TO_POINTER(CALL_STATUS_INCOMING),
+				at_util_call_compare_by_status))
 		return;
 
 	g_at_result_iter_init(&iter, result);
@@ -203,7 +194,7 @@ static void cring_notify(GAtResult *result, gpointer user_data)
 	id = ofono_voicecall_get_next_callid(vc);
 
 	/* Generate an incoming call */
-	create_call(vc, type, 1, 4, NULL, 128, 2, id);
+	create_call(vc, type, 1, CALL_STATUS_INCOMING, NULL, 128, 2, id);
 
 	/* Assume the CLIP always arrives, and we signal the call there */
 	DBG("%d", type);
@@ -219,8 +210,9 @@ static void clip_notify(GAtResult *result, gpointer user_data)
 	GSList *l;
 	struct ofono_call *call;
 
-	l = g_slist_find_custom(vd->calls, GINT_TO_POINTER(4),
-					at_util_call_compare_by_status);
+	l = g_slist_find_custom(vd->calls,
+				GINT_TO_POINTER(CALL_STATUS_INCOMING),
+				at_util_call_compare_by_status);
 	if (l == NULL) {
 		ofono_error("CLIP for unknown call");
 		return;
@@ -318,8 +310,9 @@ static void orig_notify(GAtResult *result, gpointer user_data)
 
 	ofono_info("Call origin: id %d type %d", call_id, call_type);
 
-	call = create_call(vc, call_type, 0, 2, NULL, 128, 2, call_id);
-	if (!call) {
+	call = create_call(vc, call_type, 0, CALL_STATUS_DIALING, NULL, 128, 2,
+			    call_id);
+	if (call == NULL) {
 		ofono_error("Unable to malloc, call tracking will fail!");
 		return;
 	}
@@ -356,7 +349,7 @@ static void conf_notify(GAtResult *result, gpointer user_data)
 
 	/* Set call to alerting */
 	call = l->data;
-	call->status = 3;
+	call->status = CALL_STATUS_ALERTING;
 
 	if (call->type == 0)
 		ofono_voicecall_notify(vc, call);
@@ -393,7 +386,7 @@ static void conn_notify(GAtResult *result, gpointer user_data)
 
 	/* Set call to active */
 	call = l->data;
-	call->status = 0;
+	call->status = CALL_STATUS_ACTIVE;
 
 	if (call->type == 0)
 		ofono_voicecall_notify(vc, call);
@@ -472,7 +465,7 @@ static int huawei_voicecall_probe(struct ofono_voicecall *vc,
 	struct voicecall_data *vd;
 
 	vd = g_try_new0(struct voicecall_data, 1);
-	if (!vd)
+	if (vd == NULL)
 		return -ENOMEM;
 
 	vd->chat = g_at_chat_clone(chat);
@@ -508,12 +501,12 @@ static struct ofono_voicecall_driver driver = {
 	.release_specific	= huawei_release_specific,
 };
 
-void huawei_voicecall_init()
+void huawei_voicecall_init(void)
 {
 	ofono_voicecall_driver_register(&driver);
 }
 
-void huawei_voicecall_exit()
+void huawei_voicecall_exit(void)
 {
 	ofono_voicecall_driver_unregister(&driver);
 }
