@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -143,7 +143,7 @@ static void dump_details(struct sms *sms)
 	}
 }
 
-static void test_simple_deliver()
+static void test_simple_deliver(void)
 {
 	struct sms sms;
 	unsigned char *decoded_pdu;
@@ -214,7 +214,7 @@ static void test_simple_deliver()
 	g_free(utf8);
 }
 
-static void test_alnum_sender()
+static void test_alnum_sender(void)
 {
 	struct sms sms;
 	unsigned char *decoded_pdu;
@@ -285,7 +285,7 @@ static void test_alnum_sender()
 	g_free(utf8);
 }
 
-static void test_deliver_encode()
+static void test_deliver_encode(void)
 {
 	struct sms sms;
 	unsigned char *decoded_pdu;
@@ -361,7 +361,7 @@ static void test_deliver_encode()
 	g_free(encoded_pdu);
 }
 
-static void test_simple_submit()
+static void test_simple_submit(void)
 {
 	struct sms sms;
 	unsigned char *decoded_pdu;
@@ -427,7 +427,7 @@ static void test_simple_submit()
 	g_free(utf8);
 }
 
-static void test_submit_encode()
+static void test_submit_encode(void)
 {
 	struct sms sms;
 	unsigned char *decoded_pdu;
@@ -931,7 +931,7 @@ static const char *assembly_pdu3 = "038121F340048155550119906041001222044A0500"
 					"00431044B043B0020043D04300433002E";
 static int assembly_pdu_len3 = 89;
 
-static void test_assembly()
+static void test_assembly(void)
 {
 	unsigned char pdu[176];
 	long pdu_len;
@@ -1018,7 +1018,7 @@ static const char *expected_no_fragmentation_7bit = "079153485002020911000C915"
 			"348870420140000A71154747A0E4ACF41F4F29C9E769F4121";
 static const char *sc_addr = "+358405202090";
 static const char *da_addr = "+358478400241";
-static void test_prepare_7bit()
+static void test_prepare_7bit(void)
 {
 	GSList *r;
 	struct sms *sms;
@@ -1205,7 +1205,7 @@ static void test_limit(gunichar uni, int target_size, gboolean use_16bit)
 	g_free(utf8);
 }
 
-static void test_prepare_limits()
+static void test_prepare_limits(void)
 {
 	gunichar ascii = 0x41;
 	gunichar ucs2 = 0x416;
@@ -1236,7 +1236,7 @@ static const char *cbs2 = "0110003201114679785E96371A8D46A3D168341A8D46A3D1683"
 	"41A8D46A3D168341A8D46A3D168341A8D46A3D168341A8D46A3D168341A8D46A3D168"
 	"341A8D46A3D168341A8D46A3D168341A8D46A3D168341A8D46A3D100";
 
-static void test_cbs_encode_decode()
+static void test_cbs_encode_decode(void)
 {
 	unsigned char *decoded_pdu;
 	long pdu_len;
@@ -1301,7 +1301,7 @@ static void test_cbs_encode_decode()
 	g_free(encoded_pdu);
 }
 
-static void test_cbs_assembly()
+static void test_cbs_assembly(void)
 {
 	unsigned char *decoded_pdu;
 	long pdu_len;
@@ -1389,65 +1389,13 @@ static void test_cbs_assembly()
 	cbs_assembly_free(assembly);
 }
 
-static void test_serialize_assembly()
-{
-	unsigned char pdu[176];
-	long pdu_len;
-	struct sms sms;
-	struct sms_assembly *assembly = sms_assembly_new("1234");
-	guint16 ref;
-	guint8 max;
-	guint8 seq;
-	GSList *l;
-
-	decode_hex_own_buf(assembly_pdu1, -1, &pdu_len, 0, pdu);
-	sms_decode(pdu, pdu_len, FALSE, assembly_pdu_len1, &sms);
-
-	sms_extract_concatenation(&sms, &ref, &max, &seq);
-	l = sms_assembly_add_fragment(assembly, &sms, time(NULL),
-					&sms.deliver.oaddr, ref, max, seq);
-
-	if (g_test_verbose()) {
-		g_print("Ref: %u\n", ref);
-		g_print("Max: %u\n", max);
-		g_print("From: %s\n",
-				sms_address_to_string(&sms.deliver.oaddr));
-	}
-
-	g_assert(g_slist_length(assembly->assembly_list) == 1);
-	g_assert(l == NULL);
-
-	decode_hex_own_buf(assembly_pdu2, -1, &pdu_len, 0, pdu);
-	sms_decode(pdu, pdu_len, FALSE, assembly_pdu_len2, &sms);
-
-	sms_extract_concatenation(&sms, &ref, &max, &seq);
-	l = sms_assembly_add_fragment(assembly, &sms, time(NULL),
-					&sms.deliver.oaddr, ref, max, seq);
-	g_assert(l == NULL);
-
-	sms_assembly_free(assembly);
-
-	assembly = sms_assembly_new("1234");
-
-	decode_hex_own_buf(assembly_pdu3, -1, &pdu_len, 0, pdu);
-	sms_decode(pdu, pdu_len, FALSE, assembly_pdu_len3, &sms);
-
-	sms_extract_concatenation(&sms, &ref, &max, &seq);
-	l = sms_assembly_add_fragment(assembly, &sms, time(NULL),
-					&sms.deliver.oaddr, ref, max, seq);
-
-	g_assert(l != NULL);
-
-	sms_assembly_free(assembly);
-}
-
 static const char *ranges[] = { "1-5, 2, 3, 600, 569-900, 999",
 				"0-20, 33, 44, 50-60, 20-50, 1-5, 5, 3, 5",
 				NULL };
 static const char *inv_ranges[] = { "1-5, 3333", "1-5, afbcd", "1-5, 3-5,,",
 					"1-5, 3-5, c", NULL };
 
-static void test_range_minimizer()
+static void test_range_minimizer(void)
 {
 	int i = 0;
 
@@ -1480,7 +1428,7 @@ static void test_range_minimizer()
 	}
 }
 
-static void test_sr_assembly()
+static void test_sr_assembly(void)
 {
 	const char *sr_pdu1 = "06040D91945152991136F00160124130340A0160124130"
 				"940A00";
@@ -1731,9 +1679,6 @@ int main(int argc, char **argv)
 			test_cbs_encode_decode);
 	g_test_add_func("/testsms/Test CBS Assembly", test_cbs_assembly);
 
-	g_test_add_func("/testsms/Test SMS Assembly Serialize",
-			test_serialize_assembly);
-
 	g_test_add_func("/testsms/Range minimizer", test_range_minimizer);
 
 	g_test_add_func("/testsms/Status Report Assembly", test_sr_assembly);
